@@ -25,26 +25,6 @@
 #include <perror.h>
 #endif
 
-/* NOTE: do not use "bool" as a type in an external interface.  It could
-   have different definitions on either side of the interface.  Even if both
-   sides include this interface header file, the conditional compilation
-   here means one side may use the typedef below and the other side may
-   use some other definition.  For an external interface, be safe and just
-   use "int".
-*/
-
-#ifndef TRUE
-#define TRUE 1
-#define FALSE 0
-/* C++ has a "bool" type built in. */
-#ifndef __cplusplus
-typedef int bool;
-#endif
-#elif defined(__DECC)
-/* Tru64 defines TRUE in standard header files, but not bool. 2001.09.21 */
-typedef int bool;
-#endif
-
 #undef max
 #define max(a,b) ((a) > (b) ? (a) : (b))
 #undef min
@@ -217,25 +197,6 @@ pm_check(FILE * const file, const enum pm_check_type check_type,
          const unsigned int need_raster_size,
          enum pm_check_code * const retval_p);
 
-
-/* By making this <> instead of "", we avoid making shhopt.h a dependency
-   of every program in the package when we do make dep.
-*/
-#include <pm_shhopt.h>
-
-/* Use pm_optParseOptions instead of optParseOptions in order to use the
-   shared Netpbm libraries
-*/
-void 
-pm_optParseOptions(int * const argc, char *argv[],
-                   optStruct opt[], int const allowNegNum);
-void 
-pm_optParseOptions2(int * const argc, char *argv[],
-                    const optStruct2 opt, const unsigned long flags);
-void
-pm_optParseOptions3(int * const argc_p, char *argv[], const optStruct3 opt, 
-                 const unsigned int optStructSize, const unsigned long flags);
-
 char *
 pm_arg0toprogname(const char arg0[]);
 
