@@ -77,6 +77,38 @@ typedef signed int int32n;
 #endif
 
 
+/* NOTE: do not use "bool" as a type in an external interface.  It could
+   have different definitions on either side of the interface.  Even if both
+   sides include this interface header file, the conditional compilation
+   here means one side may use the typedef below and the other side may
+   use some other definition.  For an external interface, be safe and just
+   use "int".
+*/
+
+/* We used to assume that if TRUE was defined, then bool was too.
+   However, we had a report on 2001.09.21 of a Tru64 system that had
+   TRUE but not bool and on 2002.03.21 of an AIX 4.3 system that was
+   likewise.  So now we define bool all the time, unless the macro
+   HAVE_BOOL is defined.  If someone is using the Netpbm libraries and
+   also another library that defines bool, he can either make the
+   other library define/respect HAVE_BOOL or just define HAVE_BOOL in
+   the file that includes pm_config.h or with a compiler option.  Note
+   that C++ always has bool.  
+*/
+#ifndef TRUE
+#define TRUE 1
+#endif
+#ifndef FALSE
+#define FALSE 0
+#endif
+/* C++ has a "bool" type built in. */
+#ifndef __cplusplus
+#ifndef HAVE_BOOL
+#define HAVE_BOOL 1
+typedef int bool;
+#endif
+#endif
+
 /* CONFIGURE: If you have an X11-style rgb color names file, define its
 ** path here.  This is used by PPM to parse color names into rgb values.
 ** If you don't have such a file, comment this out and use the alternative
@@ -90,9 +122,9 @@ typedef signed int int32n;
 #define RGB_DB2 "PBMplus_Dir:RGB.TXT"
 #define RGB_DB3 "PBMplus_Dir:RGB.TXT"
 #else
-#define RGB_DB1 "/usr/X11R6/lib/X11/rgb.txt"
-#define RGB_DB2 "/usr/X11R6/lib/X11/rgb.txt"
-#define RGB_DB3 "/usr/X11R6/lib/X11/rgb.txt"
+#define RGB_DB1 "%%X11BASE%%/lib/X11/rgb.txt"
+#define RGB_DB2 "%%X11BASE%%/lib/X11/rgb.txt"
+#define RGB_DB3 "%%X11BASE%%/lib/X11/rgb.txt"
 #endif
 
 /* CONFIGURE: This is the name of an environment variable that tells
@@ -254,9 +286,13 @@ extern int write();
 */
 #ifndef __GNUC__
 #ifndef __inline__
+#ifdef __sgi
+#define __inline__ __inline
+#else
 #define __inline__
 #endif
 #endif
+#endif
 
 /* CONFIGURE: Some systems seem to need more than standard program linkage
    to get a data (as opposed to function) item out of a library.
